--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.Rendering.OpenGL.Raw.EXT.RescaleNormal
-- Copyright   :  (c) Sven Panne 2015
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- The <https://www.opengl.org/registry/specs/EXT/rescale_normal.txt EXT_rescale_normal> extension.
--
--------------------------------------------------------------------------------

module Graphics.Rendering.OpenGL.Raw.EXT.RescaleNormal (
  -- * Enums
  gl_RESCALE_NORMAL_EXT
) where

import Graphics.Rendering.OpenGL.Raw.Tokens
